@@ -9,7 +9,7 @@
 #'                 a sequence of dates. This sequence has to be in the same format as the second column (time-section).
 #' @param endog_data Character. The column name of the endogenous variable. You can only provide one endogenous variable at a time.
 #' @param cumul_mult Boolean. Estimate cumulative multipliers? TRUE (default) or FALSE. If TRUE, cumulative responses
-#'                   are estimated via: \deqn{y_(t+h) - y_(t-1),} where h = 0,..., H-1.
+#'                   are estimated via: \deqn{y_{(t+h)} - y_{(t-1)},} where h = 0,..., H-1.
 #' @param shock      Character. The column name of the variable to shock with.
 #' @param diff_shock Boolean. Take first differences of the shock variable? TRUE (default) or FALSE.
 #' @param iv_reg     Boolean. Use instrument variable approach? TRUE or FALSE.
@@ -52,8 +52,9 @@
 #'
 #'\item{irf_lin_up}{A \link{matrix}, containing all upper confidence bands.
 #'                                   The columns are the horizons.}
-#'
-#'\item{reg_summaries}{Regression output for each horizon.}
+#'\item{reg_outputs}{Full regression output (plm object) for each horizon.}
+#'\item{reg_summaries}{Summary of regression output for each horizon. In case of robust covariance estimators,
+#'this only includes the t-tests.}
 #'
 #'\item{xy_data_sets}{Data sets with endogenous and exogenous variables for each horizon.}
 #'
@@ -481,6 +482,7 @@ lp_lin_panel <- function(
 
 
   # List to store regression results
+  reg_outputs      <- list(rep(NaN), specs$hor)
   reg_summaries    <- list(rep(NaN), specs$hor)
   xy_data_sets     <- list(rep(NaN), specs$hor)
 
@@ -578,19 +580,20 @@ lp_lin_panel <- function(
       # Estimate robust covariance matrices
       if(specs$robust_cov %in% c("vcovBK", "vcovDC", "vcovHC", "vcovNW", "vcovSCC")){
 
-
-      reg_results <- get_robust_cov_panel(panel_results, specs)
+      reg_output_tmp  <- panel_results
+      reg_summary_tmp <- get_robust_cov_panel(panel_results, specs)
 
                                    } else {
 
-      reg_results <-  lmtest::coeftest(panel_results,  vcov = get_robust_vcxt_panel(specs$robust_cov))
+      reg_output_tmp  <- panel_results
+      reg_summary_tmp <-  lmtest::coeftest(panel_results,  vcov = get_robust_vcxt_panel(specs$robust_cov))
 
                                    }
 
 
 
       # Extract the position of the parameters of the shock variable
-        shock_position <- which(stats::variable.names(t(reg_results)) == specs$shock)
+        shock_position <- which(stats::variable.names(t(reg_summary_tmp)) == specs$shock)
 
       # If shock variable could not be found, stop estimation and give message
       if(is.integer(shock_position) && length(shock_position) == 0){
@@ -601,16 +604,17 @@ lp_lin_panel <- function(
 
 
       # Estimate irfs and confidence bands
-      irf_panel_mean[[1, ii]]   <- reg_results[shock_position, 1]
-      irf_panel_up[[1,   ii]]   <- reg_results[shock_position, 1] + specs$confint*reg_results[shock_position, 2]
-      irf_panel_low[[1,  ii]]   <- reg_results[shock_position, 1] - specs$confint*reg_results[shock_position, 2]
+      irf_panel_mean[[1, ii]]   <- reg_summary_tmp[shock_position, 1]
+      irf_panel_up[[1,   ii]]   <- reg_summary_tmp[shock_position, 1] + specs$confint*reg_summary_tmp[shock_position, 2]
+      irf_panel_low[[1,  ii]]   <- reg_summary_tmp[shock_position, 1] - specs$confint*reg_summary_tmp[shock_position, 2]
 
                              }      else      {
 
-      reg_results <- summary(panel_results)
+      reg_output_tmp  <- panel_results
+      reg_summary_tmp <- summary(panel_results)
 
       # Extract the position of the parameters of the shock variable
-      shock_position <- which(stats::variable.names(t(reg_results$coef)) == specs$shock)
+      shock_position <- which(stats::variable.names(t(reg_summary_tmp$coef)) == specs$shock)
 
       # If shock variable could not be found, stop estimation and give message
       if(is.integer(shock_position) && length(shock_position) == 0){
@@ -619,15 +623,16 @@ lp_lin_panel <- function(
       }
 
       # Estimate irfs and confidence bands
-      irf_panel_mean[[1, ii]]   <- reg_results$coefficients[shock_position, 1]
-      irf_panel_up[[1,   ii]]   <- reg_results$coefficients[shock_position, 1] + specs$confint*reg_results$coefficients[shock_position, 2]
-      irf_panel_low[[1,  ii]]   <- reg_results$coefficients[shock_position, 1] - specs$confint*reg_results$coefficients[shock_position, 2]
+      irf_panel_mean[[1, ii]]   <- reg_summary_tmp$coefficients[shock_position, 1]
+      irf_panel_up[[1,   ii]]   <- reg_summary_tmp$coefficients[shock_position, 1] + specs$confint*reg_summary_tmp$coefficients[shock_position, 2]
+      irf_panel_low[[1,  ii]]   <- reg_summary_tmp$coefficients[shock_position, 1] - specs$confint*reg_summary_tmp$coefficients[shock_position, 2]
 
     }
 
 
     # Save regression results and data_sets
-    reg_summaries[[ii]]       <- reg_results
+    reg_outputs[[ii]]         <- reg_output_tmp
+    reg_summaries[[ii]]       <- reg_summary_tmp
     xy_data_sets[[ii]]        <- yx_data
   }
 
@@ -635,6 +640,7 @@ lp_lin_panel <- function(
   result <- list(irf_panel_mean            = irf_panel_mean,
                           irf_panel_low    = irf_panel_low,
                           irf_panel_up     = irf_panel_up,
+                          reg_outputs      = reg_outputs,
                           reg_summaries    = reg_summaries,
                           xy_data_sets     = xy_data_sets,
                           y_data           = y_data,
