@@ -12,8 +12,9 @@
 #'                   This option is only available for \emph{lags_criterion = NaN}.
 #' @param instr Deprecated input name. Use \emph{shock} instead. See \emph{shock} for details.
 #' @param exog_data A \link{data.frame}, containing exogenous variables. The row length has to be the same as \emph{endog_data}.
-#'                  Lag lengths for exogenous variables have to be given and will no be determined via a lag length criterion.
-#' @param lags_exog NULL or Integer. Integer for the number of lags for the exogenous data.
+#'                  Lag lengths for exogenous variables have to be given and will not be determined via a lag length criterion.
+#' @param lags_exog NULL or Integer. Integer for the number of lags for the exogenous data. The value cannot be 0. If you want to
+#'                  to include exogenous data with contemporaneous impact use \emph{contemp_data}.
 #' @param contemp_data A \link{data.frame}, containing exogenous data with contemporaneous impact. This data will not be lagged.
 #'                      The row length has to be the same as \emph{endog_data}.
 #' @param lags_criterion NaN or character. NaN means that the number of lags
@@ -296,6 +297,13 @@ lp_nl_iv <- function(endog_data,
     stop('The number of horizons has to be an integer and > 0.')
   }
 
+  # Check whether lags_exog < 1
+  if(!is.null(lags_exog)){
+    if(lags_exog < 1){
+      stop("'lags_exog' cannot be 0 or negative. If you want to include exogenous data with contemporaneous impact use 'contemp_data'.")
+    }
+  }
+
   # Create list to store inputs
     specs <- list()
 
